# RPM spec file for octopus.
# This file is used to build Redhat Package Manager packages for the
# octopus.  Such packages make it easy to install and uninstall
# the library and related files from binaries or source.
#
# This spec file is for version 4.1.2 of octopus; the appropriate
# version numbers are automatically substituted in to octopus.spec.in
# by the configure script.  However, octopus.spec.in may need to be
# modified for future releases, if the list of installed files
# or build commands change.
#
# RPM.  To build, use the command: rpm --clean -ba octopus.spec
#
# Alternatively, you can just use 'make rpm'.
#
Name: octopus
Summary: Real-space, real-time, TDDFT code
Version: 4.1.2
Release: 2%{?dist}
License: GPLv2
BuildRoot: %{_tmppath}/%{name}-%{version}-buildroot
Source: http://www.tddft.org/programs/octopus/download/%{name}-%{version}.tar.gz
URL: http://www.tddft.org/programs/octopus
BuildRequires: openmpi-devel fftw-devel gcc-gfortran arpack-devel
BuildRequires: netcdf-devel gsl-devel libxc-devel fftw-devel
BuildRequires: openblas-devel gd-devel zoltan-devel
# for tests
BuildRequires: perl-Time-HiRes
Requires: %name-common = %version-%release

%global desc \
octopus is a computer package aimed at the simulation of the electron-ion\
dynamics of finite systems, both in one and three dimensions, under the\
influence of time-dependent electromagnetic fields. The electronic degrees\
of freedom are treated quantum mechanically within the time-dependent\
Kohn-Sham formalism, while the ions are handled classically. All quantities\
are expanded in a regular mesh in real space, and the simulations are\
performed in real time. Although not optimized for that purpose, the\
program is also able to obtain static properties like ground-state geometries,\
or static polarizabilities. The method employed proved quite reliable and\
general, and has been successfully used to calculate linear and non-linear\
absorption spectra, harmonic spectra, laser induced fragmentation, etc.\
of a variety of systems, from small clusters to medium sized quantum dots.

%description
%desc

This is the serial version.

%package openmpi
Summary: real-space, real-time, TDDFT code - openmpi
Requires: %name-common = %version-%release
Requires: openmpi

%description openmpi
%desc

This is the openmpi version.

%package common
Summary: Common files for %name
BuildArch: noarch

%description common
Common files for %name

%package devel
Summary: Development files for %name
Requires: %name = %version-%release

%description devel
Development files for %name

%package openmpi-devel
Summary: Development files for %name-openmpi
Requires: %name-openmpi = %version-%release, openmpi-devel

%description openmpi-devel
Development files for %name-openmpi

%prep
rm -rf $RPM_BUILD_ROOT
%setup -q
mkdir serial openmpi

# The installation is also performed in the %%build stage because the
# code has to be configured twice, with and without MPI support, and
# cleaned in between.
%build

%global _configure ../configure
pushd openmpi
%_openmpi_load
%configure \
  FC="mpif90" \
  FCFLAGS="-I/usr/lib64/gfortran/modules -O3 -funroll-loops" \
  LIBS_BLAS="-lopenblas" \
  LIBS_LAPACK="-lopenblas" \
  LIBS_FFT="-lfftw3" \
  GSL_CONFIG="/usr/bin/gsl-config" \
  --with-arpack="-larpack" \
  --with-netcdf="-lnetcdff -lnetcdf" \
  --enable-mpi \
  --disable-metis \
  --bindir=$MPI_BIN --libdir=$MPI_LIB --mandir=$MPI_MAN \
  --includedir=$MPI_INCLUDE
make %{?_smp_mflags}
popd

pushd serial
%configure \
  FC="gfortran" \
  FCFLAGS="-I/usr/lib64/gfortran/modules -O3 -funroll-loops" \
  LIBS_BLAS="-lopenblas" \
  LIBS_LAPACK="-lopenblas" \
  LIBS_FFT=" -lfftw3" \
  GSL_CONFIG="/usr/bin/gsl-config" \
  --with-arpack="-larpack" \
  --with-netcdf="-lnetcdff -lnetcdf" \
  --disable-metis
make %{?_smp_mflags}
popd


%install
rm -rf ${RPM_BUILD_ROOT}
make -C openmpi install DESTDIR=${RPM_BUILD_ROOT}
make -C serial install DESTDIR=${RPM_BUILD_ROOT}

%clean
rm -rf ${RPM_BUILD_ROOT}

%check
# one test fails in copr which works in normal mock
%if x%{?copr_username} == x
make -C serial check
%endif

%files
%doc README COPYING AUTHORS doc/pdf/*.pdf
%{_bindir}/*
%{_mandir}/man1/*

%files common
%{_datadir}/octopus/*

%files devel
%{_includedir}/*
%{_libdir}/liboct_parser.a

%files openmpi
%{_libdir}/openmpi/bin/*
%{_mandir}/openmpi*/man1/*

%files openmpi-devel
%{_includedir}/openmpi*/*
%{_libdir}/openmpi/lib/liboct_parser.a


%changelog
* Wed Jan 28 2015 Dave Love <d.love@liverpool.ac.uk> - 4.1.2-2
- Heavily modified from the bundled version
- Modify tags for Fedora
- Add BRs
- Separate install stage
- Change configure xFLAGS
- Parallel build/openmpi package
- Simplify configure for GSL
- Add common package
- Remove attempt to build octopus.ps
- Fix spaces in configure args causing trouble
- Link against openblas
- Run (serial) tests
- Remove post actions (no info file installed)
